@@ -2,13 +2,29 @@ from flask import Markup, url_for
 from babel.dates import format_date, format_datetime
 
 
+def _single_get(item, key):
+    # First, try to lookup the key as if the item were a dict. If
+    # that fails, lookup the key as an atrribute of an item.
+    try:
+        val = item[key]
+    except (KeyError, TypeError):
+        val = getattr(item, key)
+
+    # once we have the value, try calling it as a function. If
+    # that fails, the just return it.
+    try:
+        return val()
+    except TypeError:
+        return val
+
+
 def _recursive_getattr(item, keys):
     if item is None:
         return None
     if len(keys) == 1:
-        return getattr(item, keys[0])
+        return _single_get(item, keys[0])
     else:
-        return _recursive_getattr(getattr(item, keys[0]), keys[1:])
+        return _recursive_getattr(_single_get(item, keys[0]), keys[1:])
 
 
 class Col(object):
@@ -42,11 +58,11 @@ class Col(object):
 
     def get_attr_list(self, attr):
         if self.attr:
-            return [self.attr]
+            return self.attr.split('.')
         elif self.attr_list:
             return self.attr_list
         elif attr:
-            return [attr]
+            return attr.split('.')
         else:
             return None
 
